@@ -22,7 +22,7 @@
 #	verbose - Should status updates be printed
 
 
-e.cp3o = function(Z, K=1, delta=29, alpha=1, eps=0.01, verbose=FALSE){
+e.cp3o_delta = function(Z, K=1, delta=29, alpha=1, verbose=FALSE){
 	#Argument checking
 	if(!is.matrix(Z))
 		stop("Z must be an n x d matrix.")
@@ -32,8 +32,6 @@ e.cp3o = function(Z, K=1, delta=29, alpha=1, eps=0.01, verbose=FALSE){
 		stop("delta must be a positive integer greater than 1.")
 	if(K < 1 || K > floor(nrow(Z)/(delta+1)))
 		stop("K is not in an acceptable range.")
-	if(eps <= 0 || eps >= 1)
-		stop("eps must be in the interval (0,1).")
 	#Force K and delta to be integers
 	delta = as.integer(delta)
 	K = as.integer(K)
@@ -41,20 +39,43 @@ e.cp3o = function(Z, K=1, delta=29, alpha=1, eps=0.01, verbose=FALSE){
 	#Call C++ code that implements the method and store result in res
 	#Also keep track of time
 	t1 = proc.time()
-	res = eFastC(Z, K, delta, alpha, eps, verbose)
+	res = eFastC_delta(Z, K, delta, alpha, verbose)
 	t2 = proc.time()
 	res$time = as.numeric((t2-t1)[3])
 	#Correct for the fact that C++ is zero based
 	#res$estimates = res$estimates + 1
-	#res$cpLoc = res$cpLoc + 1
 
 	return(res)
 }
 
 #Function arguments are as follows (in addition to above):
 #	minsize - minimum distance between changepoints
+
+e.cp3o = function(Z, K=1, minsize=30, alpha=1, verbose=FALSE){
+	#Argument checking
+	if(!is.matrix(Z))
+		stop("Z must be an n x d matrix.")
+	if(K < 1)
+		stop("K is not in an acceptable range.")
+	if(minsize < 1)
+		stop("minsize must be a positive integer greater than 0.")
+
+	#Force K and delta to be integers
+	K = as.integer(K)
+
+	#Call C++ code that implements the method and store result in res
+	#Also keep track of time
+	t1 = proc.time()
+	res = eFastC(Z, K, minsize, alpha, verbose)
+	t2 = proc.time()
+	res$time = as.numeric((t2-t1)[3])
+	#Correct for the fact that C++ is zero based
+	#res$estimates = res$estimates + 1
+
+	return(res)
+}
   
-ks.cp3o = function(Z, K=1, minsize=30, eps=0.01, verbose=FALSE){
+ks.cp3o = function(Z, K=1, minsize=30, verbose=FALSE){
   #Argument checking
   if(!is.matrix(Z))
     stop("Z must be an n x d matrix.")
@@ -62,8 +83,6 @@ ks.cp3o = function(Z, K=1, minsize=30, eps=0.01, verbose=FALSE){
     stop("K is not in an acceptable range.")
   if(minsize < 1)
     stop("minsize must be a positive integer greater than 0.")
-  if(eps <= 0 || eps >=1)
-    stop("eps must be in the interval (0,1).")
   
   #Force K and delta to be integers
   K = as.integer(K)
@@ -71,13 +90,36 @@ ks.cp3o = function(Z, K=1, minsize=30, eps=0.01, verbose=FALSE){
   #Call C++ code that implements the method and store result in res
   #Also keep track of time
   t1 = proc.time()
-  res = ksFastC(Z, K, minsize, eps, verbose)
+  res = ksFastC(Z, K, minsize, verbose)
   t2 = proc.time()
   res$time = as.numeric((t2-t1)[3])
   #Correct for the fact that C++ is zero based
   #res$estimates = res$estimates + 1
-  #res$cpLoc = res$cpLoc + 1
   
   return(res)
 }  
-  
\ No newline at end of file
+ 
+ks.cp3o_delta = function(Z, K=1, minsize=30, verbose=FALSE){
+  #Argument checking
+  if(!is.matrix(Z))
+    stop("Z must be an n x d matrix.")
+  if(K < 1)
+    stop("K is not in an acceptable range.")
+  if(minsize < 1)
+    stop("minsize must be a positive integer greater than 0.")
+  
+  #Force K and delta to be integers
+  K = as.integer(K)
+  
+  #Call C++ code that implements the method and store result in res
+  #Also keep track of time
+  t1 = proc.time()
+  res = ksFastC_delta(Z, K, minsize, verbose)
+  t2 = proc.time()
+  res$time = as.numeric((t2-t1)[3])
+  #Correct for the fact that C++ is zero based
+  #res$estimates = res$estimates + 1
+  
+  return(res)
+} 
+ 
